@@ -18,7 +18,8 @@ assign("cleanEx",
        function(env = .GlobalEnv) {
 	   rm(list = ls(envir = env, all.names = TRUE), envir = env)
            RNGkind("Wichmann-Hill", "default")
-	   assign(".Random.seed", c(0, rep(7654, 3)), pos = 1)
+	   # assign(".Random.seed", c(0, rep(7654, 3)), pos = 1)
+           set.seed(290875)
 	   assign("T", NULL, pos = 1);
 	   assign("F", NULL, pos = 1);
        },
